# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.reporting_rich_insights_config import ReportingRichInsightsConfig

class TestReportingRichInsightsConfig(unittest.TestCase):
    """ReportingRichInsightsConfig unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ReportingRichInsightsConfig:
        """Test ReportingRichInsightsConfig
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ReportingRichInsightsConfig`
        """
        model = ReportingRichInsightsConfig()
        if include_optional:
            return ReportingRichInsightsConfig(
                content = neurograph.v1.models.reporting/content_config.reporting.ContentConfig(
                    chart_defaults = neurograph.v1.models.reporting/chart_defaults.reporting.ChartDefaults(
                        options = neurograph.v1.models.reporting/chart_options.reporting.ChartOptions(
                            maintain_aspect_ratio = True, 
                            plugins = {
                                'key' : None
                                }, 
                            responsive = True, 
                            scales = {
                                'key' : None
                                }, ), ), 
                    header = neurograph.v1.models.reporting/header_config.reporting.HeaderConfig(
                        subtitle = '', 
                        title = '', ), 
                    primary_analysis = neurograph.v1.models.reporting/primary_analysis.reporting.PrimaryAnalysis(
                        exploration_topics = [
                            neurograph.v1.models.reporting/exploration_topic.reporting.ExplorationTopic(
                                context = {
                                    'key' : None
                                    }, 
                                query = '', 
                                title = '', )
                            ], 
                        key_findings = [
                            ''
                            ], 
                        summary = '', ), 
                    visualizations = [
                        neurograph.v1.models.reporting/visualization.reporting.Visualization(
                            data = neurograph.v1.models.reporting/chart_data.reporting.ChartData(
                                datasets = [
                                    neurograph.v1.models.reporting/chart_dataset.reporting.ChartDataset(
                                        background_color = '', 
                                        bar_percentage = 1.337, 
                                        label = '', )
                                    ], 
                                labels = [
                                    ''
                                    ], ), 
                            id = '', 
                            insights = neurograph.v1.models.reporting/visualization_insights.reporting.VisualizationInsights(
                                bullets = [
                                    ''
                                    ], 
                                summary = '', 
                                title = '', ), 
                            title = '', 
                            type = '', )
                        ], ),
                meta = neurograph.v1.models.reporting/meta_config.reporting.MetaConfig(
                    analysis_type = '', 
                    data_range = neurograph.v1.models.reporting/data_range.reporting.DataRange(
                        end = '', 
                        start = '', ), 
                    entity_subtype = '', 
                    entity_type = '', 
                    generated_at = '', )
            )
        else:
            return ReportingRichInsightsConfig(
        )
        """

    def testReportingRichInsightsConfig(self):
        """Test ReportingRichInsightsConfig"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from pydantic import Field, StrictStr
from typing import Optional
from typing_extensions import Annotated
from neurograph.v1.models.reporting_affinities_response import ReportingAffinitiesResponse
from neurograph.v1.models.reporting_customer_activity_response import ReportingCustomerActivityResponse
from neurograph.v1.models.reporting_daily_metrics_response import ReportingDailyMetricsResponse
from neurograph.v1.models.reporting_persona_activity_response import ReportingPersonaActivityResponse
from neurograph.v1.models.reporting_personas_response import ReportingPersonasResponse
from neurograph.v1.models.reporting_query import ReportingQuery
from neurograph.v1.models.reporting_rich_insights_config import ReportingRichInsightsConfig

from neurograph.v1.api_client import ApiClient, RequestSerialized
from neurograph.v1.api_response import ApiResponse
from neurograph.v1.rest import RESTResponseType


class ReportingApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    def api_v1_reporting_affinities_get(
        self,
        start_date: Annotated[StrictStr, Field(description="Start date (YYYY-MM-DD)")],
        end_date: Annotated[StrictStr, Field(description="End date (YYYY-MM-DD)")],
        persona_name: Annotated[Optional[StrictStr], Field(description="Persona name")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ReportingAffinitiesResponse:
        """Get customer affinities

        Get affinities by persona (or all)

        :param start_date: Start date (YYYY-MM-DD) (required)
        :type start_date: str
        :param end_date: End date (YYYY-MM-DD) (required)
        :type end_date: str
        :param persona_name: Persona name
        :type persona_name: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v1_reporting_affinities_get_serialize(
            start_date=start_date,
            end_date=end_date,
            persona_name=persona_name,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ReportingAffinitiesResponse",
            '503': "ReportingAffinitiesResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def api_v1_reporting_affinities_get_with_http_info(
        self,
        start_date: Annotated[StrictStr, Field(description="Start date (YYYY-MM-DD)")],
        end_date: Annotated[StrictStr, Field(description="End date (YYYY-MM-DD)")],
        persona_name: Annotated[Optional[StrictStr], Field(description="Persona name")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[ReportingAffinitiesResponse]:
        """Get customer affinities

        Get affinities by persona (or all)

        :param start_date: Start date (YYYY-MM-DD) (required)
        :type start_date: str
        :param end_date: End date (YYYY-MM-DD) (required)
        :type end_date: str
        :param persona_name: Persona name
        :type persona_name: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v1_reporting_affinities_get_serialize(
            start_date=start_date,
            end_date=end_date,
            persona_name=persona_name,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ReportingAffinitiesResponse",
            '503': "ReportingAffinitiesResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def api_v1_reporting_affinities_get_without_preload_content(
        self,
        start_date: Annotated[StrictStr, Field(description="Start date (YYYY-MM-DD)")],
        end_date: Annotated[StrictStr, Field(description="End date (YYYY-MM-DD)")],
        persona_name: Annotated[Optional[StrictStr], Field(description="Persona name")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get customer affinities

        Get affinities by persona (or all)

        :param start_date: Start date (YYYY-MM-DD) (required)
        :type start_date: str
        :param end_date: End date (YYYY-MM-DD) (required)
        :type end_date: str
        :param persona_name: Persona name
        :type persona_name: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v1_reporting_affinities_get_serialize(
            start_date=start_date,
            end_date=end_date,
            persona_name=persona_name,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ReportingAffinitiesResponse",
            '503': "ReportingAffinitiesResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _api_v1_reporting_affinities_get_serialize(
        self,
        start_date,
        end_date,
        persona_name,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if persona_name is not None:
            
            _query_params.append(('persona_name', persona_name))
            
        if start_date is not None:
            
            _query_params.append(('start_date', start_date))
            
        if end_date is not None:
            
            _query_params.append(('end_date', end_date))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'TokenAuth', 
            'ApiKeyAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/v1/reporting/affinities/',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def api_v1_reporting_client_uid_get(
        self,
        client_uid: Annotated[StrictStr, Field(description="client's uid, eg. arthaus")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ReportingRichInsightsConfig:
        """Get AI Summary by Client UID

        Get AI Summary by Client UID

        :param client_uid: client's uid, eg. arthaus (required)
        :type client_uid: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v1_reporting_client_uid_get_serialize(
            client_uid=client_uid,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ReportingRichInsightsConfig",
            '503': "ReportingRichInsightsConfig",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def api_v1_reporting_client_uid_get_with_http_info(
        self,
        client_uid: Annotated[StrictStr, Field(description="client's uid, eg. arthaus")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[ReportingRichInsightsConfig]:
        """Get AI Summary by Client UID

        Get AI Summary by Client UID

        :param client_uid: client's uid, eg. arthaus (required)
        :type client_uid: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v1_reporting_client_uid_get_serialize(
            client_uid=client_uid,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ReportingRichInsightsConfig",
            '503': "ReportingRichInsightsConfig",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def api_v1_reporting_client_uid_get_without_preload_content(
        self,
        client_uid: Annotated[StrictStr, Field(description="client's uid, eg. arthaus")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get AI Summary by Client UID

        Get AI Summary by Client UID

        :param client_uid: client's uid, eg. arthaus (required)
        :type client_uid: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v1_reporting_client_uid_get_serialize(
            client_uid=client_uid,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ReportingRichInsightsConfig",
            '503': "ReportingRichInsightsConfig",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _api_v1_reporting_client_uid_get_serialize(
        self,
        client_uid,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if client_uid is not None:
            _path_params['client_uid'] = client_uid
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/v1/reporting/{client_uid}/',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def api_v1_reporting_customer_activity_get(
        self,
        start_date: Annotated[StrictStr, Field(description="Start date (YYYY-MM-DD)")],
        end_date: Annotated[StrictStr, Field(description="End date (YYYY-MM-DD)")],
        interval: Annotated[Optional[StrictStr], Field(description="Interval (day|week|month)")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ReportingCustomerActivityResponse:
        """Get customer activity metrics

        Get visitors, conversions, LTV, revenue lift by persona

        :param start_date: Start date (YYYY-MM-DD) (required)
        :type start_date: str
        :param end_date: End date (YYYY-MM-DD) (required)
        :type end_date: str
        :param interval: Interval (day|week|month)
        :type interval: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v1_reporting_customer_activity_get_serialize(
            start_date=start_date,
            end_date=end_date,
            interval=interval,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ReportingCustomerActivityResponse",
            '503': "ReportingCustomerActivityResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def api_v1_reporting_customer_activity_get_with_http_info(
        self,
        start_date: Annotated[StrictStr, Field(description="Start date (YYYY-MM-DD)")],
        end_date: Annotated[StrictStr, Field(description="End date (YYYY-MM-DD)")],
        interval: Annotated[Optional[StrictStr], Field(description="Interval (day|week|month)")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[ReportingCustomerActivityResponse]:
        """Get customer activity metrics

        Get visitors, conversions, LTV, revenue lift by persona

        :param start_date: Start date (YYYY-MM-DD) (required)
        :type start_date: str
        :param end_date: End date (YYYY-MM-DD) (required)
        :type end_date: str
        :param interval: Interval (day|week|month)
        :type interval: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v1_reporting_customer_activity_get_serialize(
            start_date=start_date,
            end_date=end_date,
            interval=interval,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ReportingCustomerActivityResponse",
            '503': "ReportingCustomerActivityResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def api_v1_reporting_customer_activity_get_without_preload_content(
        self,
        start_date: Annotated[StrictStr, Field(description="Start date (YYYY-MM-DD)")],
        end_date: Annotated[StrictStr, Field(description="End date (YYYY-MM-DD)")],
        interval: Annotated[Optional[StrictStr], Field(description="Interval (day|week|month)")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get customer activity metrics

        Get visitors, conversions, LTV, revenue lift by persona

        :param start_date: Start date (YYYY-MM-DD) (required)
        :type start_date: str
        :param end_date: End date (YYYY-MM-DD) (required)
        :type end_date: str
        :param interval: Interval (day|week|month)
        :type interval: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v1_reporting_customer_activity_get_serialize(
            start_date=start_date,
            end_date=end_date,
            interval=interval,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ReportingCustomerActivityResponse",
            '503': "ReportingCustomerActivityResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _api_v1_reporting_customer_activity_get_serialize(
        self,
        start_date,
        end_date,
        interval,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if start_date is not None:
            
            _query_params.append(('start_date', start_date))
            
        if end_date is not None:
            
            _query_params.append(('end_date', end_date))
            
        if interval is not None:
            
            _query_params.append(('interval', interval))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'TokenAuth', 
            'ApiKeyAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/v1/reporting/customer-activity/',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def api_v1_reporting_daily_rollup_post(
        self,
        request: Annotated[ReportingQuery, Field(description="Body")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ReportingDailyMetricsResponse:
        """Get Daily Metrics for Client by Persona


        :param request: Body (required)
        :type request: ReportingQuery
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v1_reporting_daily_rollup_post_serialize(
            request=request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ReportingDailyMetricsResponse",
            '400': "ReportingDailyMetricsResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def api_v1_reporting_daily_rollup_post_with_http_info(
        self,
        request: Annotated[ReportingQuery, Field(description="Body")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[ReportingDailyMetricsResponse]:
        """Get Daily Metrics for Client by Persona


        :param request: Body (required)
        :type request: ReportingQuery
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v1_reporting_daily_rollup_post_serialize(
            request=request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ReportingDailyMetricsResponse",
            '400': "ReportingDailyMetricsResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def api_v1_reporting_daily_rollup_post_without_preload_content(
        self,
        request: Annotated[ReportingQuery, Field(description="Body")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get Daily Metrics for Client by Persona


        :param request: Body (required)
        :type request: ReportingQuery
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v1_reporting_daily_rollup_post_serialize(
            request=request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ReportingDailyMetricsResponse",
            '400': "ReportingDailyMetricsResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _api_v1_reporting_daily_rollup_post_serialize(
        self,
        request,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if request is not None:
            _body_params = request


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'ApiKeyAuth'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/api/v1/reporting/daily-rollup/',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def api_v1_reporting_persona_activity_get(
        self,
        start_date: Annotated[StrictStr, Field(description="Start date (YYYY-MM-DD)")],
        end_date: Annotated[StrictStr, Field(description="End date (YYYY-MM-DD)")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ReportingPersonaActivityResponse:
        """Get persona activity trend

        Get daily persona activity

        :param start_date: Start date (YYYY-MM-DD) (required)
        :type start_date: str
        :param end_date: End date (YYYY-MM-DD) (required)
        :type end_date: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v1_reporting_persona_activity_get_serialize(
            start_date=start_date,
            end_date=end_date,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ReportingPersonaActivityResponse",
            '503': "ReportingPersonaActivityResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def api_v1_reporting_persona_activity_get_with_http_info(
        self,
        start_date: Annotated[StrictStr, Field(description="Start date (YYYY-MM-DD)")],
        end_date: Annotated[StrictStr, Field(description="End date (YYYY-MM-DD)")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[ReportingPersonaActivityResponse]:
        """Get persona activity trend

        Get daily persona activity

        :param start_date: Start date (YYYY-MM-DD) (required)
        :type start_date: str
        :param end_date: End date (YYYY-MM-DD) (required)
        :type end_date: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v1_reporting_persona_activity_get_serialize(
            start_date=start_date,
            end_date=end_date,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ReportingPersonaActivityResponse",
            '503': "ReportingPersonaActivityResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def api_v1_reporting_persona_activity_get_without_preload_content(
        self,
        start_date: Annotated[StrictStr, Field(description="Start date (YYYY-MM-DD)")],
        end_date: Annotated[StrictStr, Field(description="End date (YYYY-MM-DD)")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get persona activity trend

        Get daily persona activity

        :param start_date: Start date (YYYY-MM-DD) (required)
        :type start_date: str
        :param end_date: End date (YYYY-MM-DD) (required)
        :type end_date: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v1_reporting_persona_activity_get_serialize(
            start_date=start_date,
            end_date=end_date,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ReportingPersonaActivityResponse",
            '503': "ReportingPersonaActivityResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _api_v1_reporting_persona_activity_get_serialize(
        self,
        start_date,
        end_date,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if start_date is not None:
            
            _query_params.append(('start_date', start_date))
            
        if end_date is not None:
            
            _query_params.append(('end_date', end_date))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'TokenAuth', 
            'ApiKeyAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/v1/reporting/persona-activity/',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def api_v1_reporting_personas_legacy_get(
        self,
        start_date: Annotated[StrictStr, Field(description="Start date (YYYY-MM-DD)")],
        end_date: Annotated[StrictStr, Field(description="End date (YYYY-MM-DD)")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ReportingPersonasResponse:
        """Get persona rollup

        Get monthly persona stats

        :param start_date: Start date (YYYY-MM-DD) (required)
        :type start_date: str
        :param end_date: End date (YYYY-MM-DD) (required)
        :type end_date: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v1_reporting_personas_legacy_get_serialize(
            start_date=start_date,
            end_date=end_date,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ReportingPersonasResponse",
            '503': "ReportingPersonasResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def api_v1_reporting_personas_legacy_get_with_http_info(
        self,
        start_date: Annotated[StrictStr, Field(description="Start date (YYYY-MM-DD)")],
        end_date: Annotated[StrictStr, Field(description="End date (YYYY-MM-DD)")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[ReportingPersonasResponse]:
        """Get persona rollup

        Get monthly persona stats

        :param start_date: Start date (YYYY-MM-DD) (required)
        :type start_date: str
        :param end_date: End date (YYYY-MM-DD) (required)
        :type end_date: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v1_reporting_personas_legacy_get_serialize(
            start_date=start_date,
            end_date=end_date,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ReportingPersonasResponse",
            '503': "ReportingPersonasResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def api_v1_reporting_personas_legacy_get_without_preload_content(
        self,
        start_date: Annotated[StrictStr, Field(description="Start date (YYYY-MM-DD)")],
        end_date: Annotated[StrictStr, Field(description="End date (YYYY-MM-DD)")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get persona rollup

        Get monthly persona stats

        :param start_date: Start date (YYYY-MM-DD) (required)
        :type start_date: str
        :param end_date: End date (YYYY-MM-DD) (required)
        :type end_date: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v1_reporting_personas_legacy_get_serialize(
            start_date=start_date,
            end_date=end_date,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ReportingPersonasResponse",
            '503': "ReportingPersonasResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _api_v1_reporting_personas_legacy_get_serialize(
        self,
        start_date,
        end_date,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if start_date is not None:
            
            _query_params.append(('start_date', start_date))
            
        if end_date is not None:
            
            _query_params.append(('end_date', end_date))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'TokenAuth', 
            'ApiKeyAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/v1/reporting/personas-legacy/',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )





# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, StrictFloat, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional, Union
from typing import Optional, Set
from typing_extensions import Self

class KnowledgeEnrichmentArtifactCreateRequest(BaseModel):
    """
    KnowledgeEnrichmentArtifactCreateRequest
    """ # noqa: E501
    client_id: Optional[StrictStr] = None
    cloud_run_job_name: Optional[StrictStr] = None
    confidence: Optional[Union[StrictFloat, StrictInt]] = None
    config_entity_id: Optional[StrictStr] = None
    config_snapshot: Optional[Dict[str, Any]] = None
    input_params: Optional[Dict[str, Any]] = None
    job_name: Optional[StrictStr] = None
    kind: Optional[StrictStr] = None
    output_json: Optional[Dict[str, Any]] = None
    output_schema_id: Optional[StrictStr] = None
    output_text: Optional[StrictStr] = None
    spec_version: Optional[StrictInt] = None
    subject_entity_id: Optional[StrictStr] = None
    supersedes_artifact_id: Optional[StrictInt] = None
    task_name: Optional[StrictStr] = None
    task_queue_name: Optional[StrictStr] = None
    __properties: ClassVar[List[str]] = ["client_id", "cloud_run_job_name", "confidence", "config_entity_id", "config_snapshot", "input_params", "job_name", "kind", "output_json", "output_schema_id", "output_text", "spec_version", "subject_entity_id", "supersedes_artifact_id", "task_name", "task_queue_name"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of KnowledgeEnrichmentArtifactCreateRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of KnowledgeEnrichmentArtifactCreateRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "client_id": obj.get("client_id"),
            "cloud_run_job_name": obj.get("cloud_run_job_name"),
            "confidence": obj.get("confidence"),
            "config_entity_id": obj.get("config_entity_id"),
            "config_snapshot": obj.get("config_snapshot"),
            "input_params": obj.get("input_params"),
            "job_name": obj.get("job_name"),
            "kind": obj.get("kind"),
            "output_json": obj.get("output_json"),
            "output_schema_id": obj.get("output_schema_id"),
            "output_text": obj.get("output_text"),
            "spec_version": obj.get("spec_version"),
            "subject_entity_id": obj.get("subject_entity_id"),
            "supersedes_artifact_id": obj.get("supersedes_artifact_id"),
            "task_name": obj.get("task_name"),
            "task_queue_name": obj.get("task_queue_name")
        })
        return _obj





# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.reporting_primary_analysis import ReportingPrimaryAnalysis

class TestReportingPrimaryAnalysis(unittest.TestCase):
    """ReportingPrimaryAnalysis unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ReportingPrimaryAnalysis:
        """Test ReportingPrimaryAnalysis
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ReportingPrimaryAnalysis`
        """
        model = ReportingPrimaryAnalysis()
        if include_optional:
            return ReportingPrimaryAnalysis(
                exploration_topics = [
                    neurograph.v1.models.reporting/exploration_topic.reporting.ExplorationTopic(
                        context = {
                            'key' : None
                            }, 
                        query = '', 
                        title = '', )
                    ],
                key_findings = [
                    ''
                    ],
                summary = ''
            )
        else:
            return ReportingPrimaryAnalysis(
        )
        """

    def testReportingPrimaryAnalysis(self):
        """Test ReportingPrimaryAnalysis"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.knowledge_entity_upsert_request import KnowledgeEntityUpsertRequest

class TestKnowledgeEntityUpsertRequest(unittest.TestCase):
    """KnowledgeEntityUpsertRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> KnowledgeEntityUpsertRequest:
        """Test KnowledgeEntityUpsertRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `KnowledgeEntityUpsertRequest`
        """
        model = KnowledgeEntityUpsertRequest()
        if include_optional:
            return KnowledgeEntityUpsertRequest(
                batch_id = '',
                data = [
                    neurograph.v1.models.knowledge/entity.knowledge.Entity(
                        client_id = 'cli_...', 
                        data = neurograph.v1.models.data.data(), 
                        ext = neurograph.v1.models.knowledge/entity_extra.knowledge.EntityExtra(
                            customer_id = 56, 
                            domain = '', 
                            product_id = 56, ), 
                        extra = neurograph.v1.models.extra.extra(), 
                        kind = 'Product|Customer|Store', 
                        name = 'GiBoard Gel', 
                        relations = neurograph.v1.models.knowledge/entity_relations.knowledge.EntityRelations(
                            children = [[ent_789]], 
                            parents = [[ent_123,  ent_456]], 
                            siblings = [[ent_999]], ), 
                        schema = neurograph.v1.models.knowledge/entity_schema.knowledge.EntitySchema(
                            id = '@axon/commerce/product:1.0.0', 
                            params = neurograph.v1.models.params.params(), ), 
                        source_id = '', 
                        source_updated_at = 56, 
                        ts_updated = 56, )
                    ]
            )
        else:
            return KnowledgeEntityUpsertRequest(
        )
        """

    def testKnowledgeEntityUpsertRequest(self):
        """Test KnowledgeEntityUpsertRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

# flake8: noqa

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "1.0.0"

# Define package exports
__all__ = [
    "AdminApi",
    "AuthenticationApi",
    "ClientApi",
    "ClientMetadataApi",
    "DagsterApi",
    "KnowledgeApi",
    "KnowledgeExtractApi",
    "LookupApi",
    "OrganizationApi",
    "OrganizationMetadataApi",
    "PersonaApi",
    "ReportingApi",
    "SystemApi",
    "UserApi",
    "WorkbenchApi",
    "ApiResponse",
    "ApiClient",
    "Configuration",
    "OpenApiException",
    "ApiTypeError",
    "ApiValueError",
    "ApiKeyError",
    "ApiAttributeError",
    "ApiException",
    "AdminPermissionResponse",
    "AdminSetPermissionRequest",
    "AdminUpsertUserRequest",
    "AdminUpsertUserResponse",
    "AdminUser",
    "AdminUserDetailResponse",
    "AdminUsersGetManyResponse",
    "AdminUsersOrgResponse",
    "AuthServiceTokenRequest",
    "AuthServiceTokenResponse",
    "AuthTestServiceTokenRequest",
    "AuthTestServiceTokenResponse",
    "AuthTestTokenResponse",
    "ClientClient",
    "ClientDeleteMetadataRequest",
    "ClientGetDetailResponse",
    "ClientGetManyResponse",
    "ClientInfo",
    "ClientKpi",
    "ClientMetadata",
    "ClientMetadataRequest",
    "ClientMetadataResponse",
    "ClientOrganizationBrand",
    "ClientOrganizationDetail",
    "ClientPersona",
    "ClientPersonaFactor",
    "ClientPersonaInsight",
    "ClientPersonaPersonalityTrait",
    "ClientPersonasResponse",
    "ClientProbe",
    "ClientProbeTodoRow",
    "ClientQuery",
    "ClientTriggerProbeResponse",
    "ClientURLSnapshotResponse",
    "ClientUpsertRequest",
    "ClientUpsertResponse",
    "ClientUrlRow",
    "ClientUrlSnapshotRow",
    "ClientUrlUpsertRequest",
    "ClientUrlUpsertResponse",
    "ClientUrlsResponse",
    "ClientWorkbenchConfig",
    "DagsterInfo",
    "DagsterLogCreateRequest",
    "DagsterLogCreateResponse",
    "DagsterLogGetResponse",
    "DbAccountOrganizationBrand",
    "DbClientUrl",
    "DbKnowledgeCustomer",
    "DbKnowledgeOrder",
    "DbKnowledgeProduct",
    "DbKnowledgeStore",
    "DbMyClient",
    "DbMyOrg",
    "DbPersonaFactorCreateParams",
    "DbUserClientRole",
    "DbUserInDb",
    "DbUserOrgRole",
    "DbUserRole",
    "KnowledgeAssertion",
    "KnowledgeAssertionCreateRequest",
    "KnowledgeAssertionListResponse",
    "KnowledgeAssertionQuery",
    "KnowledgeAssertionResponse",
    "KnowledgeCustomerQuery",
    "KnowledgeCustomerResponse",
    "KnowledgeEnrichmentArtifact",
    "KnowledgeEnrichmentArtifactCreateRequest",
    "KnowledgeEnrichmentArtifactListResponse",
    "KnowledgeEnrichmentArtifactResponse",
    "KnowledgeEnrichmentArtifactUpdateOutputRequest",
    "KnowledgeEnrichmentArtifactUpdateStatusRequest",
    "KnowledgeEnrichmentQuery",
    "KnowledgeEntity",
    "KnowledgeEntityCreateRequest",
    "KnowledgeEntityCreateResponse",
    "KnowledgeEntityErrRow",
    "KnowledgeEntityExtra",
    "KnowledgeEntityGetManyResponse",
    "KnowledgeEntityInDb",
    "KnowledgeEntityRelations",
    "KnowledgeEntitySchema",
    "KnowledgeEntitySchemaRow",
    "KnowledgeEntitySchemaUpsertRequest",
    "KnowledgeEntitySchemasResponse",
    "KnowledgeEntitySchemasUpsertResponse",
    "KnowledgeEntityTypeResponse",
    "KnowledgeEntityTypeRow",
    "KnowledgeEntityTypeUpsertRequest",
    "KnowledgeEntityTypeUpsertRow",
    "KnowledgeEntityUpsertRequest",
    "KnowledgeEntityUpsertResponse",
    "KnowledgeIngestRawRequest",
    "KnowledgeIngestRawResponse",
    "KnowledgeIngestRawRow",
    "KnowledgeKindResponse",
    "KnowledgeOrderQuery",
    "KnowledgeOrderResponse",
    "KnowledgeProduct",
    "KnowledgeProductQuery",
    "KnowledgeProductResponse",
    "KnowledgeProductUpsertRequest",
    "KnowledgeProductUpsertResponse",
    "KnowledgeQuery",
    "KnowledgeStoreQuery",
    "KnowledgeStoreResponse",
    "LookupEnv",
    "LookupLanguage",
    "LookupLanguageResponse",
    "LookupLookupEnvironmentsResponse",
    "LookupRole",
    "LookupRolesResponse",
    "LookupState",
    "LookupStateResponse",
    "LookupStatesResponse",
    "LookupUid",
    "LookupUidsResponse",
    "MeMyProfileResponse",
    "OrganizationsBrand",
    "OrganizationsBrandDetailResponse",
    "OrganizationsBrandUpsertRequest",
    "OrganizationsCreateRequest",
    "OrganizationsDeleteMetadataRequest",
    "OrganizationsDeleteMetadataResponse",
    "OrganizationsDetailResponse",
    "OrganizationsGetManyResponse",
    "OrganizationsMetadata",
    "OrganizationsMetadataRequest",
    "OrganizationsMetadataResponse",
    "OrganizationsOrganization",
    "OrganizationsOrganizationSetWorkbenchRequest",
    "OrganizationsOrganizationSetWorkbenchResponse",
    "OrganizationsOrganizationUpdateRequest",
    "OrganizationsWorkbenchConfig",
    "PersonasFactorCreateRequest",
    "PersonasFactorCreateResponse",
    "PersonasFactorRow",
    "PersonasInsightCreateRequest",
    "PersonasInsightCreateResponse",
    "PersonasInstanceCreateRequest",
    "PersonasInstanceCreateResponse",
    "PersonasInstanceDeleteManyRequest",
    "PersonasInstanceDeleteManyResponse",
    "PersonasInstancesResponse",
    "PersonasKpi",
    "PersonasKpiCreateRequest",
    "PersonasKpiCreateResponse",
    "PersonasKpiReqRow",
    "PersonasKpiRowInDb",
    "PersonasMatchCriteriaRequest",
    "PersonasMatchCriteriaResponse",
    "PersonasMatchCriteriaRowIn",
    "PersonasMatchCriteriaRowInDb",
    "PersonasPersona",
    "PersonasPersonaFactor",
    "PersonasPersonaInsight",
    "PersonasPersonaPersonalityTrait",
    "PersonasPersonalityTraitCreateRequest",
    "PersonasPersonalityTraitCreateResponse",
    "PersonasPersonalityTraitInDb",
    "PersonasPersonalityTraitReq",
    "PersonasSeed",
    "PersonasSeedGetManyResponse",
    "PersonasSeedUpsertRequest",
    "PersonasSeedsDeleteResponse",
    "PgtypeInfinityModifier",
    "PgtypeInt8",
    "PgtypeText",
    "PgtypeTimestamp",
    "ReportingAffinitiesResponse",
    "ReportingChartData",
    "ReportingChartDataset",
    "ReportingChartDefaults",
    "ReportingChartOptions",
    "ReportingContentConfig",
    "ReportingCustomerActivityResponse",
    "ReportingDailyMetric",
    "ReportingDailyMetricsResponse",
    "ReportingDataRange",
    "ReportingExplorationTopic",
    "ReportingHeaderConfig",
    "ReportingMetaConfig",
    "ReportingPersonaActivityResponse",
    "ReportingPersonasResponse",
    "ReportingPrimaryAnalysis",
    "ReportingQuery",
    "ReportingRichInsightsConfig",
    "ReportingVisualization",
    "ReportingVisualizationInsights",
    "WorkbenchWorkbenchUrlCheckRequest",
    "WorkbenchWorkbenchUrlCheckResponse",
    "WorkbenchWorkbenchVersion",
    "WorkbenchWorkbenchVersionManyResponse",
    "WorkbenchWorkbenchVersionResponse",
    "WorkbenchWorkbenchVersionUpsertRequest",
]

# import apis into sdk package
from neurograph.v1.api.admin_api import AdminApi as AdminApi
from neurograph.v1.api.authentication_api import AuthenticationApi as AuthenticationApi
from neurograph.v1.api.client_api import ClientApi as ClientApi
from neurograph.v1.api.client_metadata_api import ClientMetadataApi as ClientMetadataApi
from neurograph.v1.api.dagster_api import DagsterApi as DagsterApi
from neurograph.v1.api.knowledge_api import KnowledgeApi as KnowledgeApi
from neurograph.v1.api.knowledge_extract_api import KnowledgeExtractApi as KnowledgeExtractApi
from neurograph.v1.api.lookup_api import LookupApi as LookupApi
from neurograph.v1.api.organization_api import OrganizationApi as OrganizationApi
from neurograph.v1.api.organization_metadata_api import OrganizationMetadataApi as OrganizationMetadataApi
from neurograph.v1.api.persona_api import PersonaApi as PersonaApi
from neurograph.v1.api.reporting_api import ReportingApi as ReportingApi
from neurograph.v1.api.system_api import SystemApi as SystemApi
from neurograph.v1.api.user_api import UserApi as UserApi
from neurograph.v1.api.workbench_api import WorkbenchApi as WorkbenchApi

# import ApiClient
from neurograph.v1.api_response import ApiResponse as ApiResponse
from neurograph.v1.api_client import ApiClient as ApiClient
from neurograph.v1.configuration import Configuration as Configuration
from neurograph.v1.exceptions import OpenApiException as OpenApiException
from neurograph.v1.exceptions import ApiTypeError as ApiTypeError
from neurograph.v1.exceptions import ApiValueError as ApiValueError
from neurograph.v1.exceptions import ApiKeyError as ApiKeyError
from neurograph.v1.exceptions import ApiAttributeError as ApiAttributeError
from neurograph.v1.exceptions import ApiException as ApiException

# import models into sdk package
from neurograph.v1.models.admin_permission_response import AdminPermissionResponse as AdminPermissionResponse
from neurograph.v1.models.admin_set_permission_request import AdminSetPermissionRequest as AdminSetPermissionRequest
from neurograph.v1.models.admin_upsert_user_request import AdminUpsertUserRequest as AdminUpsertUserRequest
from neurograph.v1.models.admin_upsert_user_response import AdminUpsertUserResponse as AdminUpsertUserResponse
from neurograph.v1.models.admin_user import AdminUser as AdminUser
from neurograph.v1.models.admin_user_detail_response import AdminUserDetailResponse as AdminUserDetailResponse
from neurograph.v1.models.admin_users_get_many_response import AdminUsersGetManyResponse as AdminUsersGetManyResponse
from neurograph.v1.models.admin_users_org_response import AdminUsersOrgResponse as AdminUsersOrgResponse
from neurograph.v1.models.auth_service_token_request import AuthServiceTokenRequest as AuthServiceTokenRequest
from neurograph.v1.models.auth_service_token_response import AuthServiceTokenResponse as AuthServiceTokenResponse
from neurograph.v1.models.auth_test_service_token_request import AuthTestServiceTokenRequest as AuthTestServiceTokenRequest
from neurograph.v1.models.auth_test_service_token_response import AuthTestServiceTokenResponse as AuthTestServiceTokenResponse
from neurograph.v1.models.auth_test_token_response import AuthTestTokenResponse as AuthTestTokenResponse
from neurograph.v1.models.client_client import ClientClient as ClientClient
from neurograph.v1.models.client_delete_metadata_request import ClientDeleteMetadataRequest as ClientDeleteMetadataRequest
from neurograph.v1.models.client_get_detail_response import ClientGetDetailResponse as ClientGetDetailResponse
from neurograph.v1.models.client_get_many_response import ClientGetManyResponse as ClientGetManyResponse
from neurograph.v1.models.client_info import ClientInfo as ClientInfo
from neurograph.v1.models.client_kpi import ClientKpi as ClientKpi
from neurograph.v1.models.client_metadata import ClientMetadata as ClientMetadata
from neurograph.v1.models.client_metadata_request import ClientMetadataRequest as ClientMetadataRequest
from neurograph.v1.models.client_metadata_response import ClientMetadataResponse as ClientMetadataResponse
from neurograph.v1.models.client_organization_brand import ClientOrganizationBrand as ClientOrganizationBrand
from neurograph.v1.models.client_organization_detail import ClientOrganizationDetail as ClientOrganizationDetail
from neurograph.v1.models.client_persona import ClientPersona as ClientPersona
from neurograph.v1.models.client_persona_factor import ClientPersonaFactor as ClientPersonaFactor
from neurograph.v1.models.client_persona_insight import ClientPersonaInsight as ClientPersonaInsight
from neurograph.v1.models.client_persona_personality_trait import ClientPersonaPersonalityTrait as ClientPersonaPersonalityTrait
from neurograph.v1.models.client_personas_response import ClientPersonasResponse as ClientPersonasResponse
from neurograph.v1.models.client_probe import ClientProbe as ClientProbe
from neurograph.v1.models.client_probe_todo_row import ClientProbeTodoRow as ClientProbeTodoRow
from neurograph.v1.models.client_query import ClientQuery as ClientQuery
from neurograph.v1.models.client_trigger_probe_response import ClientTriggerProbeResponse as ClientTriggerProbeResponse
from neurograph.v1.models.client_url_snapshot_response import ClientURLSnapshotResponse as ClientURLSnapshotResponse
from neurograph.v1.models.client_upsert_request import ClientUpsertRequest as ClientUpsertRequest
from neurograph.v1.models.client_upsert_response import ClientUpsertResponse as ClientUpsertResponse
from neurograph.v1.models.client_url_row import ClientUrlRow as ClientUrlRow
from neurograph.v1.models.client_url_snapshot_row import ClientUrlSnapshotRow as ClientUrlSnapshotRow
from neurograph.v1.models.client_url_upsert_request import ClientUrlUpsertRequest as ClientUrlUpsertRequest
from neurograph.v1.models.client_url_upsert_response import ClientUrlUpsertResponse as ClientUrlUpsertResponse
from neurograph.v1.models.client_urls_response import ClientUrlsResponse as ClientUrlsResponse
from neurograph.v1.models.client_workbench_config import ClientWorkbenchConfig as ClientWorkbenchConfig
from neurograph.v1.models.dagster_info import DagsterInfo as DagsterInfo
from neurograph.v1.models.dagster_log_create_request import DagsterLogCreateRequest as DagsterLogCreateRequest
from neurograph.v1.models.dagster_log_create_response import DagsterLogCreateResponse as DagsterLogCreateResponse
from neurograph.v1.models.dagster_log_get_response import DagsterLogGetResponse as DagsterLogGetResponse
from neurograph.v1.models.db_account_organization_brand import DbAccountOrganizationBrand as DbAccountOrganizationBrand
from neurograph.v1.models.db_client_url import DbClientUrl as DbClientUrl
from neurograph.v1.models.db_knowledge_customer import DbKnowledgeCustomer as DbKnowledgeCustomer
from neurograph.v1.models.db_knowledge_order import DbKnowledgeOrder as DbKnowledgeOrder
from neurograph.v1.models.db_knowledge_product import DbKnowledgeProduct as DbKnowledgeProduct
from neurograph.v1.models.db_knowledge_store import DbKnowledgeStore as DbKnowledgeStore
from neurograph.v1.models.db_my_client import DbMyClient as DbMyClient
from neurograph.v1.models.db_my_org import DbMyOrg as DbMyOrg
from neurograph.v1.models.db_persona_factor_create_params import DbPersonaFactorCreateParams as DbPersonaFactorCreateParams
from neurograph.v1.models.db_user_client_role import DbUserClientRole as DbUserClientRole
from neurograph.v1.models.db_user_in_db import DbUserInDb as DbUserInDb
from neurograph.v1.models.db_user_org_role import DbUserOrgRole as DbUserOrgRole
from neurograph.v1.models.db_user_role import DbUserRole as DbUserRole
from neurograph.v1.models.knowledge_assertion import KnowledgeAssertion as KnowledgeAssertion
from neurograph.v1.models.knowledge_assertion_create_request import KnowledgeAssertionCreateRequest as KnowledgeAssertionCreateRequest
from neurograph.v1.models.knowledge_assertion_list_response import KnowledgeAssertionListResponse as KnowledgeAssertionListResponse
from neurograph.v1.models.knowledge_assertion_query import KnowledgeAssertionQuery as KnowledgeAssertionQuery
from neurograph.v1.models.knowledge_assertion_response import KnowledgeAssertionResponse as KnowledgeAssertionResponse
from neurograph.v1.models.knowledge_customer_query import KnowledgeCustomerQuery as KnowledgeCustomerQuery
from neurograph.v1.models.knowledge_customer_response import KnowledgeCustomerResponse as KnowledgeCustomerResponse
from neurograph.v1.models.knowledge_enrichment_artifact import KnowledgeEnrichmentArtifact as KnowledgeEnrichmentArtifact
from neurograph.v1.models.knowledge_enrichment_artifact_create_request import KnowledgeEnrichmentArtifactCreateRequest as KnowledgeEnrichmentArtifactCreateRequest
from neurograph.v1.models.knowledge_enrichment_artifact_list_response import KnowledgeEnrichmentArtifactListResponse as KnowledgeEnrichmentArtifactListResponse
from neurograph.v1.models.knowledge_enrichment_artifact_response import KnowledgeEnrichmentArtifactResponse as KnowledgeEnrichmentArtifactResponse
from neurograph.v1.models.knowledge_enrichment_artifact_update_output_request import KnowledgeEnrichmentArtifactUpdateOutputRequest as KnowledgeEnrichmentArtifactUpdateOutputRequest
from neurograph.v1.models.knowledge_enrichment_artifact_update_status_request import KnowledgeEnrichmentArtifactUpdateStatusRequest as KnowledgeEnrichmentArtifactUpdateStatusRequest
from neurograph.v1.models.knowledge_enrichment_query import KnowledgeEnrichmentQuery as KnowledgeEnrichmentQuery
from neurograph.v1.models.knowledge_entity import KnowledgeEntity as KnowledgeEntity
from neurograph.v1.models.knowledge_entity_create_request import KnowledgeEntityCreateRequest as KnowledgeEntityCreateRequest
from neurograph.v1.models.knowledge_entity_create_response import KnowledgeEntityCreateResponse as KnowledgeEntityCreateResponse
from neurograph.v1.models.knowledge_entity_err_row import KnowledgeEntityErrRow as KnowledgeEntityErrRow
from neurograph.v1.models.knowledge_entity_extra import KnowledgeEntityExtra as KnowledgeEntityExtra
from neurograph.v1.models.knowledge_entity_get_many_response import KnowledgeEntityGetManyResponse as KnowledgeEntityGetManyResponse
from neurograph.v1.models.knowledge_entity_in_db import KnowledgeEntityInDb as KnowledgeEntityInDb
from neurograph.v1.models.knowledge_entity_relations import KnowledgeEntityRelations as KnowledgeEntityRelations
from neurograph.v1.models.knowledge_entity_schema import KnowledgeEntitySchema as KnowledgeEntitySchema
from neurograph.v1.models.knowledge_entity_schema_row import KnowledgeEntitySchemaRow as KnowledgeEntitySchemaRow
from neurograph.v1.models.knowledge_entity_schema_upsert_request import KnowledgeEntitySchemaUpsertRequest as KnowledgeEntitySchemaUpsertRequest
from neurograph.v1.models.knowledge_entity_schemas_response import KnowledgeEntitySchemasResponse as KnowledgeEntitySchemasResponse
from neurograph.v1.models.knowledge_entity_schemas_upsert_response import KnowledgeEntitySchemasUpsertResponse as KnowledgeEntitySchemasUpsertResponse
from neurograph.v1.models.knowledge_entity_type_response import KnowledgeEntityTypeResponse as KnowledgeEntityTypeResponse
from neurograph.v1.models.knowledge_entity_type_row import KnowledgeEntityTypeRow as KnowledgeEntityTypeRow
from neurograph.v1.models.knowledge_entity_type_upsert_request import KnowledgeEntityTypeUpsertRequest as KnowledgeEntityTypeUpsertRequest
from neurograph.v1.models.knowledge_entity_type_upsert_row import KnowledgeEntityTypeUpsertRow as KnowledgeEntityTypeUpsertRow
from neurograph.v1.models.knowledge_entity_upsert_request import KnowledgeEntityUpsertRequest as KnowledgeEntityUpsertRequest
from neurograph.v1.models.knowledge_entity_upsert_response import KnowledgeEntityUpsertResponse as KnowledgeEntityUpsertResponse
from neurograph.v1.models.knowledge_ingest_raw_request import KnowledgeIngestRawRequest as KnowledgeIngestRawRequest
from neurograph.v1.models.knowledge_ingest_raw_response import KnowledgeIngestRawResponse as KnowledgeIngestRawResponse
from neurograph.v1.models.knowledge_ingest_raw_row import KnowledgeIngestRawRow as KnowledgeIngestRawRow
from neurograph.v1.models.knowledge_kind_response import KnowledgeKindResponse as KnowledgeKindResponse
from neurograph.v1.models.knowledge_order_query import KnowledgeOrderQuery as KnowledgeOrderQuery
from neurograph.v1.models.knowledge_order_response import KnowledgeOrderResponse as KnowledgeOrderResponse
from neurograph.v1.models.knowledge_product import KnowledgeProduct as KnowledgeProduct
from neurograph.v1.models.knowledge_product_query import KnowledgeProductQuery as KnowledgeProductQuery
from neurograph.v1.models.knowledge_product_response import KnowledgeProductResponse as KnowledgeProductResponse
from neurograph.v1.models.knowledge_product_upsert_request import KnowledgeProductUpsertRequest as KnowledgeProductUpsertRequest
from neurograph.v1.models.knowledge_product_upsert_response import KnowledgeProductUpsertResponse as KnowledgeProductUpsertResponse
from neurograph.v1.models.knowledge_query import KnowledgeQuery as KnowledgeQuery
from neurograph.v1.models.knowledge_store_query import KnowledgeStoreQuery as KnowledgeStoreQuery
from neurograph.v1.models.knowledge_store_response import KnowledgeStoreResponse as KnowledgeStoreResponse
from neurograph.v1.models.lookup_env import LookupEnv as LookupEnv
from neurograph.v1.models.lookup_language import LookupLanguage as LookupLanguage
from neurograph.v1.models.lookup_language_response import LookupLanguageResponse as LookupLanguageResponse
from neurograph.v1.models.lookup_lookup_environments_response import LookupLookupEnvironmentsResponse as LookupLookupEnvironmentsResponse
from neurograph.v1.models.lookup_role import LookupRole as LookupRole
from neurograph.v1.models.lookup_roles_response import LookupRolesResponse as LookupRolesResponse
from neurograph.v1.models.lookup_state import LookupState as LookupState
from neurograph.v1.models.lookup_state_response import LookupStateResponse as LookupStateResponse
from neurograph.v1.models.lookup_states_response import LookupStatesResponse as LookupStatesResponse
from neurograph.v1.models.lookup_uid import LookupUid as LookupUid
from neurograph.v1.models.lookup_uids_response import LookupUidsResponse as LookupUidsResponse
from neurograph.v1.models.me_my_profile_response import MeMyProfileResponse as MeMyProfileResponse
from neurograph.v1.models.organizations_brand import OrganizationsBrand as OrganizationsBrand
from neurograph.v1.models.organizations_brand_detail_response import OrganizationsBrandDetailResponse as OrganizationsBrandDetailResponse
from neurograph.v1.models.organizations_brand_upsert_request import OrganizationsBrandUpsertRequest as OrganizationsBrandUpsertRequest
from neurograph.v1.models.organizations_create_request import OrganizationsCreateRequest as OrganizationsCreateRequest
from neurograph.v1.models.organizations_delete_metadata_request import OrganizationsDeleteMetadataRequest as OrganizationsDeleteMetadataRequest
from neurograph.v1.models.organizations_delete_metadata_response import OrganizationsDeleteMetadataResponse as OrganizationsDeleteMetadataResponse
from neurograph.v1.models.organizations_detail_response import OrganizationsDetailResponse as OrganizationsDetailResponse
from neurograph.v1.models.organizations_get_many_response import OrganizationsGetManyResponse as OrganizationsGetManyResponse
from neurograph.v1.models.organizations_metadata import OrganizationsMetadata as OrganizationsMetadata
from neurograph.v1.models.organizations_metadata_request import OrganizationsMetadataRequest as OrganizationsMetadataRequest
from neurograph.v1.models.organizations_metadata_response import OrganizationsMetadataResponse as OrganizationsMetadataResponse
from neurograph.v1.models.organizations_organization import OrganizationsOrganization as OrganizationsOrganization
from neurograph.v1.models.organizations_organization_set_workbench_request import OrganizationsOrganizationSetWorkbenchRequest as OrganizationsOrganizationSetWorkbenchRequest
from neurograph.v1.models.organizations_organization_set_workbench_response import OrganizationsOrganizationSetWorkbenchResponse as OrganizationsOrganizationSetWorkbenchResponse
from neurograph.v1.models.organizations_organization_update_request import OrganizationsOrganizationUpdateRequest as OrganizationsOrganizationUpdateRequest
from neurograph.v1.models.organizations_workbench_config import OrganizationsWorkbenchConfig as OrganizationsWorkbenchConfig
from neurograph.v1.models.personas_factor_create_request import PersonasFactorCreateRequest as PersonasFactorCreateRequest
from neurograph.v1.models.personas_factor_create_response import PersonasFactorCreateResponse as PersonasFactorCreateResponse
from neurograph.v1.models.personas_factor_row import PersonasFactorRow as PersonasFactorRow
from neurograph.v1.models.personas_insight_create_request import PersonasInsightCreateRequest as PersonasInsightCreateRequest
from neurograph.v1.models.personas_insight_create_response import PersonasInsightCreateResponse as PersonasInsightCreateResponse
from neurograph.v1.models.personas_instance_create_request import PersonasInstanceCreateRequest as PersonasInstanceCreateRequest
from neurograph.v1.models.personas_instance_create_response import PersonasInstanceCreateResponse as PersonasInstanceCreateResponse
from neurograph.v1.models.personas_instance_delete_many_request import PersonasInstanceDeleteManyRequest as PersonasInstanceDeleteManyRequest
from neurograph.v1.models.personas_instance_delete_many_response import PersonasInstanceDeleteManyResponse as PersonasInstanceDeleteManyResponse
from neurograph.v1.models.personas_instances_response import PersonasInstancesResponse as PersonasInstancesResponse
from neurograph.v1.models.personas_kpi import PersonasKpi as PersonasKpi
from neurograph.v1.models.personas_kpi_create_request import PersonasKpiCreateRequest as PersonasKpiCreateRequest
from neurograph.v1.models.personas_kpi_create_response import PersonasKpiCreateResponse as PersonasKpiCreateResponse
from neurograph.v1.models.personas_kpi_req_row import PersonasKpiReqRow as PersonasKpiReqRow
from neurograph.v1.models.personas_kpi_row_in_db import PersonasKpiRowInDb as PersonasKpiRowInDb
from neurograph.v1.models.personas_match_criteria_request import PersonasMatchCriteriaRequest as PersonasMatchCriteriaRequest
from neurograph.v1.models.personas_match_criteria_response import PersonasMatchCriteriaResponse as PersonasMatchCriteriaResponse
from neurograph.v1.models.personas_match_criteria_row_in import PersonasMatchCriteriaRowIn as PersonasMatchCriteriaRowIn
from neurograph.v1.models.personas_match_criteria_row_in_db import PersonasMatchCriteriaRowInDb as PersonasMatchCriteriaRowInDb
from neurograph.v1.models.personas_persona import PersonasPersona as PersonasPersona
from neurograph.v1.models.personas_persona_factor import PersonasPersonaFactor as PersonasPersonaFactor
from neurograph.v1.models.personas_persona_insight import PersonasPersonaInsight as PersonasPersonaInsight
from neurograph.v1.models.personas_persona_personality_trait import PersonasPersonaPersonalityTrait as PersonasPersonaPersonalityTrait
from neurograph.v1.models.personas_personality_trait_create_request import PersonasPersonalityTraitCreateRequest as PersonasPersonalityTraitCreateRequest
from neurograph.v1.models.personas_personality_trait_create_response import PersonasPersonalityTraitCreateResponse as PersonasPersonalityTraitCreateResponse
from neurograph.v1.models.personas_personality_trait_in_db import PersonasPersonalityTraitInDb as PersonasPersonalityTraitInDb
from neurograph.v1.models.personas_personality_trait_req import PersonasPersonalityTraitReq as PersonasPersonalityTraitReq
from neurograph.v1.models.personas_seed import PersonasSeed as PersonasSeed
from neurograph.v1.models.personas_seed_get_many_response import PersonasSeedGetManyResponse as PersonasSeedGetManyResponse
from neurograph.v1.models.personas_seed_upsert_request import PersonasSeedUpsertRequest as PersonasSeedUpsertRequest
from neurograph.v1.models.personas_seeds_delete_response import PersonasSeedsDeleteResponse as PersonasSeedsDeleteResponse
from neurograph.v1.models.pgtype_infinity_modifier import PgtypeInfinityModifier as PgtypeInfinityModifier
from neurograph.v1.models.pgtype_int8 import PgtypeInt8 as PgtypeInt8
from neurograph.v1.models.pgtype_text import PgtypeText as PgtypeText
from neurograph.v1.models.pgtype_timestamp import PgtypeTimestamp as PgtypeTimestamp
from neurograph.v1.models.reporting_affinities_response import ReportingAffinitiesResponse as ReportingAffinitiesResponse
from neurograph.v1.models.reporting_chart_data import ReportingChartData as ReportingChartData
from neurograph.v1.models.reporting_chart_dataset import ReportingChartDataset as ReportingChartDataset
from neurograph.v1.models.reporting_chart_defaults import ReportingChartDefaults as ReportingChartDefaults
from neurograph.v1.models.reporting_chart_options import ReportingChartOptions as ReportingChartOptions
from neurograph.v1.models.reporting_content_config import ReportingContentConfig as ReportingContentConfig
from neurograph.v1.models.reporting_customer_activity_response import ReportingCustomerActivityResponse as ReportingCustomerActivityResponse
from neurograph.v1.models.reporting_daily_metric import ReportingDailyMetric as ReportingDailyMetric
from neurograph.v1.models.reporting_daily_metrics_response import ReportingDailyMetricsResponse as ReportingDailyMetricsResponse
from neurograph.v1.models.reporting_data_range import ReportingDataRange as ReportingDataRange
from neurograph.v1.models.reporting_exploration_topic import ReportingExplorationTopic as ReportingExplorationTopic
from neurograph.v1.models.reporting_header_config import ReportingHeaderConfig as ReportingHeaderConfig
from neurograph.v1.models.reporting_meta_config import ReportingMetaConfig as ReportingMetaConfig
from neurograph.v1.models.reporting_persona_activity_response import ReportingPersonaActivityResponse as ReportingPersonaActivityResponse
from neurograph.v1.models.reporting_personas_response import ReportingPersonasResponse as ReportingPersonasResponse
from neurograph.v1.models.reporting_primary_analysis import ReportingPrimaryAnalysis as ReportingPrimaryAnalysis
from neurograph.v1.models.reporting_query import ReportingQuery as ReportingQuery
from neurograph.v1.models.reporting_rich_insights_config import ReportingRichInsightsConfig as ReportingRichInsightsConfig
from neurograph.v1.models.reporting_visualization import ReportingVisualization as ReportingVisualization
from neurograph.v1.models.reporting_visualization_insights import ReportingVisualizationInsights as ReportingVisualizationInsights
from neurograph.v1.models.workbench_workbench_url_check_request import WorkbenchWorkbenchUrlCheckRequest as WorkbenchWorkbenchUrlCheckRequest
from neurograph.v1.models.workbench_workbench_url_check_response import WorkbenchWorkbenchUrlCheckResponse as WorkbenchWorkbenchUrlCheckResponse
from neurograph.v1.models.workbench_workbench_version import WorkbenchWorkbenchVersion as WorkbenchWorkbenchVersion
from neurograph.v1.models.workbench_workbench_version_many_response import WorkbenchWorkbenchVersionManyResponse as WorkbenchWorkbenchVersionManyResponse
from neurograph.v1.models.workbench_workbench_version_response import WorkbenchWorkbenchVersionResponse as WorkbenchWorkbenchVersionResponse
from neurograph.v1.models.workbench_workbench_version_upsert_request import WorkbenchWorkbenchVersionUpsertRequest as WorkbenchWorkbenchVersionUpsertRequest




# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.admin_user_detail_response import AdminUserDetailResponse

class TestAdminUserDetailResponse(unittest.TestCase):
    """AdminUserDetailResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> AdminUserDetailResponse:
        """Test AdminUserDetailResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `AdminUserDetailResponse`
        """
        model = AdminUserDetailResponse()
        if include_optional:
            return AdminUserDetailResponse(
                clients = [
                    neurograph.v1.models.db/my_client.db.MyClient(
                        id = '', 
                        name = '', 
                        roles = [
                            neurograph.v1.models.db/user_client_role.db.UserClientRole(
                                client_id = '', 
                                id = 56, 
                                role_name = '', 
                                ts_created = 56, )
                            ], )
                    ],
                display_name = '',
                email = '',
                error = '',
                firebase_uid = '',
                id = 56,
                ng_roles = [
                    ''
                    ],
                orgs = [
                    neurograph.v1.models.db/my_org.db.MyOrg(
                        brand = neurograph.v1.models.db/account_organization_brand.db.AccountOrganizationBrand(
                            background_img_url = '', 
                            color1 = '', 
                            color2 = '', 
                            color3 = '', 
                            color4 = '', 
                            color5 = '', 
                            id = 56, 
                            logo_img_url = '', 
                            org_id = '', 
                            primary_color = '', 
                            secondary_color = '', 
                            tertiary_color = '', ), 
                        description = '', 
                        id = '', 
                        image_url = '', 
                        is_active = True, 
                        name = '', 
                        roles = [
                            neurograph.v1.models.db/user_org_role.db.UserOrgRole(
                                id = 56, 
                                org_id = '', 
                                role_name = '', 
                                ts_created = 56, )
                            ], 
                        url = '', 
                        workbench_is_active = True, 
                        workbench_url = '', 
                        workbench_url_ext = '', 
                        workbench_version_id = '', )
                    ],
                ts_created = 56,
                ts_updated = 56
            )
        else:
            return AdminUserDetailResponse(
        )
        """

    def testAdminUserDetailResponse(self):
        """Test AdminUserDetailResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.db_user_in_db import DbUserInDb

class TestDbUserInDb(unittest.TestCase):
    """DbUserInDb unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> DbUserInDb:
        """Test DbUserInDb
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `DbUserInDb`
        """
        model = DbUserInDb()
        if include_optional:
            return DbUserInDb(
                client_roles = [
                    neurograph.v1.models.db/user_client_role.db.UserClientRole(
                        client_id = '', 
                        id = 56, 
                        role_name = '', 
                        ts_created = 56, )
                    ],
                display_name = '',
                email = '',
                firebase_uid = '',
                id = 56,
                org_roles = [
                    neurograph.v1.models.db/user_org_role.db.UserOrgRole(
                        id = 56, 
                        org_id = '', 
                        role_name = '', 
                        ts_created = 56, )
                    ],
                roles = [
                    neurograph.v1.models.db/user_role.db.UserRole(
                        id = 56, 
                        role_name = '', 
                        ts_created = 56, )
                    ],
                ts_created = 56,
                ts_updated = 56
            )
        else:
            return DbUserInDb(
        )
        """

    def testDbUserInDb(self):
        """Test DbUserInDb"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.knowledge_enrichment_artifact_create_request import KnowledgeEnrichmentArtifactCreateRequest

class TestKnowledgeEnrichmentArtifactCreateRequest(unittest.TestCase):
    """KnowledgeEnrichmentArtifactCreateRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> KnowledgeEnrichmentArtifactCreateRequest:
        """Test KnowledgeEnrichmentArtifactCreateRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `KnowledgeEnrichmentArtifactCreateRequest`
        """
        model = KnowledgeEnrichmentArtifactCreateRequest()
        if include_optional:
            return KnowledgeEnrichmentArtifactCreateRequest(
                client_id = 'cli_1234',
                cloud_run_job_name = '',
                confidence = 1.337,
                config_entity_id = '',
                config_snapshot = None,
                input_params = None,
                job_name = 'customer_profile_v1',
                kind = '',
                output_json = None,
                output_schema_id = '',
                output_text = '',
                spec_version = 1,
                subject_entity_id = 'ent_123',
                supersedes_artifact_id = 56,
                task_name = '',
                task_queue_name = ''
            )
        else:
            return KnowledgeEnrichmentArtifactCreateRequest(
        )
        """

    def testKnowledgeEnrichmentArtifactCreateRequest(self):
        """Test KnowledgeEnrichmentArtifactCreateRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.reporting_visualization import ReportingVisualization

class TestReportingVisualization(unittest.TestCase):
    """ReportingVisualization unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ReportingVisualization:
        """Test ReportingVisualization
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ReportingVisualization`
        """
        model = ReportingVisualization()
        if include_optional:
            return ReportingVisualization(
                data = neurograph.v1.models.reporting/chart_data.reporting.ChartData(
                    datasets = [
                        neurograph.v1.models.reporting/chart_dataset.reporting.ChartDataset(
                            background_color = '', 
                            bar_percentage = 1.337, 
                            label = '', )
                        ], 
                    labels = [
                        ''
                        ], ),
                id = '',
                insights = neurograph.v1.models.reporting/visualization_insights.reporting.VisualizationInsights(
                    bullets = [
                        ''
                        ], 
                    summary = '', 
                    title = '', ),
                title = '',
                type = ''
            )
        else:
            return ReportingVisualization(
        )
        """

    def testReportingVisualization(self):
        """Test ReportingVisualization"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.reporting_content_config import ReportingContentConfig

class TestReportingContentConfig(unittest.TestCase):
    """ReportingContentConfig unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ReportingContentConfig:
        """Test ReportingContentConfig
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ReportingContentConfig`
        """
        model = ReportingContentConfig()
        if include_optional:
            return ReportingContentConfig(
                chart_defaults = neurograph.v1.models.reporting/chart_defaults.reporting.ChartDefaults(
                    options = neurograph.v1.models.reporting/chart_options.reporting.ChartOptions(
                        maintain_aspect_ratio = True, 
                        plugins = {
                            'key' : None
                            }, 
                        responsive = True, 
                        scales = {
                            'key' : None
                            }, ), ),
                header = neurograph.v1.models.reporting/header_config.reporting.HeaderConfig(
                    subtitle = '', 
                    title = '', ),
                primary_analysis = neurograph.v1.models.reporting/primary_analysis.reporting.PrimaryAnalysis(
                    exploration_topics = [
                        neurograph.v1.models.reporting/exploration_topic.reporting.ExplorationTopic(
                            context = {
                                'key' : None
                                }, 
                            query = '', 
                            title = '', )
                        ], 
                    key_findings = [
                        ''
                        ], 
                    summary = '', ),
                visualizations = [
                    neurograph.v1.models.reporting/visualization.reporting.Visualization(
                        data = neurograph.v1.models.reporting/chart_data.reporting.ChartData(
                            datasets = [
                                neurograph.v1.models.reporting/chart_dataset.reporting.ChartDataset(
                                    background_color = '', 
                                    bar_percentage = 1.337, 
                                    label = '', )
                                ], 
                            labels = [
                                ''
                                ], ), 
                        id = '', 
                        insights = neurograph.v1.models.reporting/visualization_insights.reporting.VisualizationInsights(
                            bullets = [
                                ''
                                ], 
                            summary = '', 
                            title = '', ), 
                        title = '', 
                        type = '', )
                    ]
            )
        else:
            return ReportingContentConfig(
        )
        """

    def testReportingContentConfig(self):
        """Test ReportingContentConfig"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.api.reporting_api import ReportingApi


class TestReportingApi(unittest.TestCase):
    """ReportingApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ReportingApi()

    def tearDown(self) -> None:
        pass

    def test_api_v1_reporting_affinities_get(self) -> None:
        """Test case for api_v1_reporting_affinities_get

        Get customer affinities
        """
        pass

    def test_api_v1_reporting_client_uid_get(self) -> None:
        """Test case for api_v1_reporting_client_uid_get

        Get AI Summary by Client UID
        """
        pass

    def test_api_v1_reporting_customer_activity_get(self) -> None:
        """Test case for api_v1_reporting_customer_activity_get

        Get customer activity metrics
        """
        pass

    def test_api_v1_reporting_daily_rollup_post(self) -> None:
        """Test case for api_v1_reporting_daily_rollup_post

        Get Daily Metrics for Client by Persona
        """
        pass

    def test_api_v1_reporting_persona_activity_get(self) -> None:
        """Test case for api_v1_reporting_persona_activity_get

        Get persona activity trend
        """
        pass

    def test_api_v1_reporting_personas_legacy_get(self) -> None:
        """Test case for api_v1_reporting_personas_legacy_get

        Get persona rollup
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.api.organization_metadata_api import OrganizationMetadataApi


class TestOrganizationMetadataApi(unittest.TestCase):
    """OrganizationMetadataApi unit test stubs"""

    def setUp(self) -> None:
        self.api = OrganizationMetadataApi()

    def tearDown(self) -> None:
        pass

    def test_api_v1_organization_metadata_org_id_delete(self) -> None:
        """Test case for api_v1_organization_metadata_org_id_delete

        Delete an organization's metadata row
        """
        pass

    def test_api_v1_organization_metadata_org_id_get(self) -> None:
        """Test case for api_v1_organization_metadata_org_id_get

        Get organization's metadata rows
        """
        pass

    def test_api_v1_organization_metadata_org_id_post(self) -> None:
        """Test case for api_v1_organization_metadata_org_id_post

        Upsert a organization's metadata
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.api.organization_api import OrganizationApi


class TestOrganizationApi(unittest.TestCase):
    """OrganizationApi unit test stubs"""

    def setUp(self) -> None:
        self.api = OrganizationApi()

    def tearDown(self) -> None:
        pass

    def test_api_v1_organizations_branding_post(self) -> None:
        """Test case for api_v1_organizations_branding_post

        Set an Organization's Branding
        """
        pass

    def test_api_v1_organizations_get(self) -> None:
        """Test case for api_v1_organizations_get

        Get Organizations
        """
        pass

    def test_api_v1_organizations_org_id_get(self) -> None:
        """Test case for api_v1_organizations_org_id_get

        Get Organization by ID or UID
        """
        pass

    def test_api_v1_organizations_org_id_users_get(self) -> None:
        """Test case for api_v1_organizations_org_id_users_get

        Organization's assigned users and their permissions
        """
        pass

    def test_api_v1_organizations_post(self) -> None:
        """Test case for api_v1_organizations_post

        Create an Organization
        """
        pass

    def test_api_v1_organizations_put(self) -> None:
        """Test case for api_v1_organizations_put

        Update an Organization
        """
        pass

    def test_api_v1_organizations_workbench_post(self) -> None:
        """Test case for api_v1_organizations_workbench_post

        Set Organization's Workbench Version
        """
        pass


if __name__ == '__main__':
    unittest.main()
